@@ -1,4 +1,4 @@
-#!/usr/bin/env python # pylint: disable=C0302
+#!/usr/bin/env python
 
 '''
 ElasticBox Confidential
@@ -31,7 +31,7 @@ REQUESTS_TIMEOUT_SECONDS = 30
 CONFIG_PATH = os.path.expanduser('~/')
 DEFAULT_TOKEN_PATH = os.path.join(CONFIG_PATH, '.eb_token')
 
-DEPLOY_SERVICE_REQUEST_SCHEMA = 'http://elasticbox.net/schemas/2014-03-17/deploy-service-request'
+DEPLOY_SERVICE_REQUEST_SCHEMA = 'http://elasticbox.net/schemas/2014-06-04/deploy-instance-request'
 
 TOKEN_URL = '/services/security/token'
 
@@ -54,7 +54,7 @@ BOXES_TEMPLATE = '{workspace_id}/boxes'
 
 USER_AGENT_HEADER = 'user-agent'
 EB_TOKEN_HEADER = 'ElasticBox-Token'
-USER_AGENT_EB = 'elasticbox-cli/2014-03-17'
+USER_AGENT_EB = 'elasticbox-cli/2014-05-23'
 
 SCRIPT_EVENTS = ['install', 'post_install', 'configure', 'post_configure', 'start', 'post_start', 'stop', 'post_stop',
                  'dispose', 'post_dispose']
@@ -304,7 +304,6 @@ class _RESTBase(object):
 
         filename = file_path.split('/')[-1]
         absolute_url = urlparse.urljoin(host_address, UPLOAD_BOX_BLOB_TEMPLATE.format(filename))
-
         _, extension = os.path.splitext(file_path)
         content_type = 'application/octet-stream'
 
@@ -853,10 +852,12 @@ class InstancesActions(_RESTBase):
         name_parts = variable_name.split('.')
         scope = '.'.join(name_parts[:-1]) if len(name_parts[:-1]) > 0 else None
         for variable in instance['variables']:
-            if variable['name'] == name_parts[-1] and variable['scope'] == scope:
-                variable['value'] = new_value
-                self.update(instance['id'], instance)
-                return
+            if variable['name'] == name_parts[-1]:
+                if ((scope is None and 'scope' not in variable) or
+                        ('scope' in variable and variable['scope'] == scope)):
+                    variable['value'] = new_value
+                    self.update(instance['id'], instance)
+                    return
 
         variable = self._obtain_variable(instance['boxes'][0], name_parts.pop(0))
         wanted_variable = self._obtain_instance_variable(instance, name_parts, variable)
